SrvClient

Struct SrvClient 

pub struct SrvClient<Resolver, Policy: Policy = Affinity> { /* private fields */ }
Client for intelligently performing operations on a service located by SRV records.

Usage

After being created by SrvClient::new or SrvClient::new_with_resolver, operations can be performed on the service pointed to by a SrvClient with the execute and execute_stream methods.

DNS Resolvers

The resolver used to lookup SRV records is determined by a client’s SrvResolver, and can be set with SrvClient::resolver.

SRV Target Selection Policies

SRV target selection order is determined by a client’s Policy, and can be set with SrvClient::policy.

Implementations

Source

impl<Resolver: Default, Policy: Policy + Default> SrvClient<Resolver, Policy>

pub fn new( srv_name: impl ToString, fallback: Url, allowed_suffixes: Option<Vec<Host>>, ) -> Self

Creates a new client for communicating with services located by srv_name.

Source

impl<Resolver, Policy: Policy + Default> SrvClient<Resolver, Policy>

pub fn new_with_resolver( srv_name: impl ToString, fallback: Url, allowed_suffixes: Option<Vec<Host>>, resolver: Resolver, ) -> Self

Creates a new client for communicating with services located by srv_name.

Source

impl<Resolver: SrvResolver, Policy: Policy> SrvClient<Resolver, Policy>

pub async fn get_fresh_uri_candidates( &self, ) -> Result<(Vec<Url>, Instant), Error<Resolver::Error>>

Gets a fresh set of SRV records from a client’s DNS resolver and parses their target/port pairs into URIs, which are returned along with the time they’re valid until–i.e., the time a cache containing these URIs should expire.

pub async fn execute<T, E, Fut>( &self, func: impl FnMut(Url) -> Fut, ) -> Result<T, E>
where E: Error, Fut: Future<Output = Result<T, E>>,

Performs an operation on a client’s SRV targets, producing the first successful result or the last error encountered if every execution of the operation was unsuccessful.

Source

impl<Resolver, Policy: Policy> SrvClient<Resolver, Policy>

pub fn srv_name(self, srv_name: impl ToString) -> Self

Sets the SRV name of the client.

pub fn resolver<R>(self, resolver: R) -> SrvClient<R, Policy>

Sets the resolver of the client.

pub fn policy<P: Policy>(self, policy: P) -> SrvClient<Resolver, P>

Sets the policy of the client.

pub fn http_scheme(self, http_scheme: Scheme) -> Self

Sets the http scheme of the client.

pub fn path_prefix(self, path_prefix: impl ToString) -> Self

Sets the path prefix of the client.